add_comma_space: Ensure Space After Comma

View source: R/add_comma_space.R

add_comma_spaceR Documentation

Ensure Space After Comma

Description

Adds a space after a comma as strip and many other functions may consider a comma separated string as one word (i.e., "one,two,three" becomes "onetwothree" rather than "one two three").

Usage

add_comma_space(x)

Arguments

x

The text variable.

Value

Returns a vector of strings with commas that have a space after them.

Examples

## Not run: 
x <- c("the,  dog,went", "I,like,it", "where are you", NA, "why", ",", ",f")
add_comma_space(x)

## End(Not run)

textclean documentation built on March 5, 2026, 9:06 a.m.