add_missing_endmark: Add Missing Endmarks

View source: R/add_missing_endmark.R

add_missing_endmarkR Documentation

Add Missing Endmarks

Description

Detect missing endmarks and replace with the desired symbol.

Usage

add_missing_endmark(x, replacement = "|", endmarks = c("?", ".", "!"), ...)

Arguments

x

The text variable.

replacement

Character string equal in length to pattern or of length one which are a replacement for matched pattern.

endmarks

The potential ending punctuation marks.

...

Additional arguments passed to has_endmark.

Value

Returns a vector with missing endmarks added.

Examples

x <- c(
    "This in a", 
    "I am funny!", 
    "An ending of sorts%", 
    "What do you want?"
)

add_missing_endmark(x)

textclean documentation built on March 5, 2026, 9:06 a.m.