replace_white: Remove White Space Characters

View source: R/replace_white.R

replace_whiteR Documentation

Remove White Space Characters

Description

Pre-process data to replace one or more white space character with a single space (this includes new line characters).

Usage

replace_white(x, ...)

Arguments

x

The character vector.

...

ignored.

Value

Returns a vector of character strings with escaped characters removed.

Examples

x <- "I go \r
    to   the \tnext line"
x
replace_white(x)

textclean documentation built on March 5, 2026, 9:06 a.m.